summaryrefslogtreecommitdiffstats
path: root/feature-active-standby-management/src/main/java/org
diff options
context:
space:
mode:
Diffstat (limited to 'feature-active-standby-management/src/main/java/org')
-rw-r--r--feature-active-standby-management/src/main/java/org/onap/policy/drools/activestandby/DroolsPdpsElectionHandler.java8
1 files changed, 4 insertions, 4 deletions
diff --git a/feature-active-standby-management/src/main/java/org/onap/policy/drools/activestandby/DroolsPdpsElectionHandler.java b/feature-active-standby-management/src/main/java/org/onap/policy/drools/activestandby/DroolsPdpsElectionHandler.java
index b0f1a12a..e9526eb7 100644
--- a/feature-active-standby-management/src/main/java/org/onap/policy/drools/activestandby/DroolsPdpsElectionHandler.java
+++ b/feature-active-standby-management/src/main/java/org/onap/policy/drools/activestandby/DroolsPdpsElectionHandler.java
@@ -992,11 +992,11 @@ public class DroolsPdpsElectionHandler implements ThreadRunningChecker {
long nowMs = now.getTime();
long waitTimerMs = waitTimerLastRunDate.getTime();
- //give it 2 times leeway
- if((nowMs - waitTimerMs) > 2*pdpUpdateInterval){
+ //give it 10 times leeway
+ if((nowMs - waitTimerMs) > 10*pdpUpdateInterval){
logger.error("checkWaitTimer: nowMs - waitTimerMs = {}"
- + ", exceeds pdpUpdateInterval + 2000 = {}"
- + "Will reschedule waitTimer timer", (nowMs - waitTimerMs), (2*pdpUpdateInterval));
+ + ", exceeds 10* pdpUpdateInterval = {}"
+ + "Will reschedule waitTimer timer", (nowMs - waitTimerMs), (10*pdpUpdateInterval));
try{
// Recalculate since the thread could have been stalled on the synchronize()